## lint
!> 格式化文件仅支持`.js` `.scss` `.vue`，忽略`.min.js`文件，忽略`dist/` `docs/` `vendor/`文件夹

?>基于[js格式化规则](https://standardjs.com/rules-zhcn.html#javascript-standard-style)做了[修改](https://github.com/DianmiFE/eslint-config-dianmife/blob/master/index.js)，基于[样式格式化规则](https://github.com/stylelint/stylelint-config-standard)做了[修改](https://github.com/DianmiFE/dm-cli/blob/master/src/lintfix/lib/stylelintrc.js)

```shell
yarn dm lint [-S -source] [-C, --commit]
- [-S -source] 格式化目录下的文件，默认为`src`
  例如：
  yarn dm lint -- -S src //格式化`src`文件夹
  可以简写为
  yarn lint
- [-C, --commit] 格式化git 暂存区的文件，用于`git hook`提交
  例如：
  yarn dm lint -- -C //格式化git暂存区的文件
  可以简写为
  yarn lint -- -C
```

## iconfont
!> 更新iconfont字体文件（其实就是将[iconfont](http://www.iconfont.cn/)字体文件做了一些转换后写入到`src/iconfont.scss`中）

```shell
yarn dm iconfont fileName
- fileName 要写入的文件名
  例如：
  yarn dm iconfont font_kuxgx2zdzrtz9f6r
  可以简写为
  yarn iconfont font_kuxgx2zdzrtz9f6r
```

## doc
!> 预览doc文档

```shell
yarn dm doc [port]
- port 要开启的端口号,不写则默认为3000
  例如：
  yarn dm doc 13001
```

## start
?> 启动服务，启动之前会先执行`yarn dm compile-pre dev-server`
```shell
yarn dm start
- 首先读取server配置 `${_DIR}/build/server.config.json` 获取host、post
- 首先读取proxy配置 `${_DIR}/build/proxy.json` 获取proxy
- 然后读取webpack配置 `${_DIR}/build/webpack.config.dev-server.js`
- 启动
可以简写为
yarn start
```

## pack
!> 执行打包命令，主要用于项目打包，输出js；[semver参考](https://github.com/npm/node-semver#prerelease-identifiers)
```shell
yarn dm pack [version] [name]
- [version] 同 npm version [major | minor | patch | premajor | preminor | prepatch | prerelease]
- 内部执行顺序
  - `yarn dm update` 更新依赖
  - `yarn dm lint` 格式化
  - `yarn dm tag fetch` 获取服务器最新的tag
  - `version = semver.valid(version)?version:semver.inc(version,name)` 获得变化后的版本号 `version`
  - `npm --no-git-tag-version version ${version}` 修改package.json版本号
  - `yarn dm build dev pd` 构建非压缩和压缩代码
  - `git add -A` 添加到暂存区
  - `git commit -m '${version}' -n` commit提交信息
  - `git tag v${version}` 创建本次打包tag
  - `git push origin v${version}` 提交tag到服务器
  - `git symbolic-ref --short -q HEAD` 获得当前分支 `branch`
  - `git push origin ${branch}` 提交分支到服务器
- 例如：
  yarn dm pack 2.2.2 //如果打包前版本号为1.0.0，输出版本号 2.2.2
  yarn dm pack major //如果打包前版本号为1.0.0，输出版本号 2.0.0
  yarn dm pack minor //如果打包前版本号为1.0.0，输出版本号 1.1.0
  yarn dm pack patch //如果打包前版本号为1.0.0，输出版本号 1.0.1
  yarn dm pack premajor //如果打包前版本号为1.0.0，输出版本号 2.0.0-0
  yarn dm pack premajor //如果打包前版本号为2.0.0-0，输出版本号 3.0.0-0
  yarn dm pack preminor //如果打包前版本号为1.0.0，输出版本号 1.1.0-0
  yarn dm pack preminor //如果打包前版本号为1.1.0-0，输出版本号 1.2.0-0
  yarn dm pack prepatch //如果打包前版本号为1.0.0，输出版本号 1.0.1-0
  yarn dm pack prepatch //如果打包前版本号为1.0.1-0，输出版本号 1.0.2-0
  yarn dm pack prerelease //如果打包前版本号为1.0.0，输出版本号 1.0.1-0
  yarn dm pack prepatch rc //如果打包前版本号为1.0.0，输出版本号 1.0.1-rc.0
  yarn dm pack prepatch rc //如果打包前版本号为1.0.1-rc.0，输出版本号 1.0.2-rc.0
  yarn dm pack prerelease rc //如果打包前版本号为1.0.0，输出版本号 1.0.1-rc.0
  yarn dm pack prerelease rc //如果打包前版本号为1.0.1-rc.0，输出版本号 1.0.1-rc.1
  yarn dm pack premajor rc //如果打包前版本号为1.0.0，输出版本号 2.0.0-rc.0
  yarn dm pack premajor rc //如果打包前版本号为2.0.0-rc.0，输出版本号 3.0.0-rc.0
  yarn dm pack preminor rc //如果打包前版本号为1.0.0，输出版本号 1.1.0-rc.0
  yarn dm pack preminor rc //如果打包前版本号为1.1.0-rc.0，输出版本号 1.2.0-rc.0
```